@@ -20,4 +20,4 @@ class UserAgentMiddleware(object):
 
     def process_request(self, request, spider):
         if self.user_agent:
-            request.headers.setdefault('User-Agent', self.user_agent)
+            request.headers.setdefault(b'User-Agent', self.user_agent)
