@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 from pydispatch import dispatcher
 from scrapy.utils import signal as _signal
 
@@ -46,16 +45,14 @@ class SignalManager(object):
 
     def send_catch_log_deferred(self, signal, **kwargs):
         """
-        Like :meth:`send_catch_log` but supports returning `deferreds`_ from
-        signal handlers.
+        Like :meth:`send_catch_log` but supports returning
+        :class:`~twisted.internet.defer.Deferred` objects from signal handlers.
 
         Returns a Deferred that gets fired once all signal handlers
         deferreds were fired. Send a signal, catch exceptions and log them.
 
         The keyword arguments are passed to the signal handlers (connected
         through the :meth:`connect` method).
-
-        .. _deferreds: https://twistedmatrix.com/documents/current/core/howto/defer.html
         """
         kwargs.setdefault('sender', self.sender)
         return _signal.send_catch_log_deferred(signal, **kwargs)
